package components.editor;

import skeleton.*;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * @author 
 * <p>&copy;Ȩ 2002, 2003
 * 廪ѧѧԺ</p>
 * @version
 * 1.00
 * <p>ͼθʽԻ</p>*/
public class ImageFormat extends JDialog
{
    private Frame owner;

    private JPanel jpTop;
    private JPanel jpBottom;

    private JLabel lbColors;

    private JPanel jpColors;
    private JRadioButton jrb2Colors;
    private JRadioButton jrb16Colors;
    private JRadioButton jrb256Colors;
    private JRadioButton jrbTrueColor;
    private ButtonGroup bgColors;

    private JPanel jpPaletteType;
    private JRadioButton jrbTypeStandard;
    private JRadioButton jrbTypeOptimize;
    private ButtonGroup bgType;

    private JPanel jpSize;
    private JRadioButton jrbSizeSmall;
    private JRadioButton jrbSizeNormal;
    private JRadioButton jrbSizeLarge;
    private JRadioButton jrbCustom;
    private JTextField jtfWidth;
    private JLabel lbCross;
    private JTextField jtfHeight;
    private ButtonGroup bgSize;

    private JButton jbOK;
    private JButton jbCancel;

    private boolean succeed;

    private ImageFormation formation;

    public static final int PALETTE_STANDARD = 0;
    public static final int PALETTE_OPTIMIZED = 1;

    public ImageFormation showDialog(ImageFormation current)
    {
        succeed = false;
        if (current != null)
            formation = current;
        else
        {
            formation = new ImageFormation();
            formation.colors = 16;
            formation.palettetype = PALETTE_STANDARD;
            formation.width = 32;
            formation.height = 32;
            formation.exact = -1;
        }

        switch (formation.colors)
        {
            case 2 :
                jrb2Colors.setSelected(true);
                break;
            case 16 :
                jrb16Colors.setSelected(true);
                break;
            case 256 :
                jrb256Colors.setSelected(true);
                break;
            case 16777216 :
                jrbTrueColor.setSelected(true);
                break;
        }

        switch (formation.palettetype)
        {
            case PALETTE_STANDARD :
                jrbTypeStandard.setSelected(true);
                break;
            case PALETTE_OPTIMIZED :
                jrbTypeOptimize.setSelected(true);
                break;
        }

        boolean state = false;

        if (formation.width == 16 && formation.height == 16)
            jrbSizeSmall.setSelected(true);
        else if (formation.width == 32 && formation.height == 32)
            jrbSizeNormal.setSelected(true);
        else if (formation.width == 48 && formation.height == 48)
            jrbSizeLarge.setSelected(true);
        else
        {
            jrbCustom.setSelected(true);
            jtfWidth.setText(String.valueOf(formation.width));
            jtfHeight.setText(String.valueOf(formation.height));
            state = true;
        }

        jtfWidth.setEnabled(state);
        jtfHeight.setEnabled(state);

        if (formation.exact == -1)
        {
            lbColors.setText("");
            jrbTypeOptimize.setEnabled(false);
        }
        else
        {
            lbColors.setText(
                Resource.FormatCurColors.replaceAll(
                    "%i",
                    String.valueOf(formation.exact)));
            jrbTypeOptimize.setEnabled(true);
        }

        try
        {
            setLocation(
                getParent().getX() + (getParent().getWidth() - getWidth()) / 2,
                getParent().getY()
                    + (getParent().getHeight() - getHeight()) / 2);
        }
        catch (NullPointerException e)
        {
            setLocation(
                (Toolkit.getDefaultToolkit().getScreenSize().width
                    - getWidth())
                    / 2,
                (Toolkit.getDefaultToolkit().getScreenSize().height
                    - getHeight())
                    / 2);
        }
        SwingUtilities.updateComponentTreeUI(this);
        show();

        if (succeed)
            return formation;
        else
            return null;
    }

    public ImageFormat(Frame Owner)
    {
        super(Owner, Resource.FormatDialogTitle, true);
        owner = Owner;

        lbColors = new JLabel(" ");

        bgColors = new ButtonGroup();

        jpColors = new JPanel();
        jpColors.setBorder(
            BorderFactory.createTitledBorder(Resource.FormatImageColors));
        jpColors.setLayout(new BoxLayout(jpColors, BoxLayout.Y_AXIS));

        jrb2Colors = new JRadioButton(Resource.Palette2Color);
        jrb2Colors.addActionListener(new ActionListener()
        {
            public void actionPerformed(ActionEvent e)
            {
                formation.colors = 2;
                jrbTypeStandard.setEnabled(true);
                jrbTypeOptimize.setEnabled(formation.exact != -1);
            }
        });

        jrb16Colors = new JRadioButton(Resource.Palette16Color);
        jrb16Colors.addActionListener(new ActionListener()
        {
            public void actionPerformed(ActionEvent e)
            {
                formation.colors = 16;
                jrbTypeStandard.setEnabled(true);
                jrbTypeOptimize.setEnabled(formation.exact != -1);
            }
        });

        jrb256Colors = new JRadioButton(Resource.Palette256Color);
        jrb256Colors.addActionListener(new ActionListener()
        {
            public void actionPerformed(ActionEvent e)
            {
                formation.colors = 256;
                jrbTypeStandard.setEnabled(true);
                jrbTypeOptimize.setEnabled(formation.exact != -1);
            }
        });

        jrbTrueColor = new JRadioButton(Resource.PaletteTrueColor);
        jrbTrueColor.addActionListener(new ActionListener()
        {
            public void actionPerformed(ActionEvent e)
            {
                formation.colors = 16777216;
                jrbTypeStandard.setEnabled(false);
                jrbTypeOptimize.setEnabled(false);
            }
        });

        bgColors.add(jrb2Colors);
        bgColors.add(jrb16Colors);
        bgColors.add(jrb256Colors);
        bgColors.add(jrbTrueColor);

        jpColors.add(jrb2Colors);
        jpColors.add(jrb16Colors);
        jpColors.add(jrb256Colors);
        jpColors.add(jrbTrueColor);

        bgType = new ButtonGroup();

        jpPaletteType = new JPanel();
        jpPaletteType.setBorder(
            BorderFactory.createTitledBorder(Resource.FormatPaletteType));
        jpPaletteType.setLayout(new BoxLayout(jpPaletteType, BoxLayout.Y_AXIS));

        jrbTypeStandard = new JRadioButton(Resource.FormatPaletteStandard);
        jrbTypeStandard.addActionListener(new ActionListener()
        {
            public void actionPerformed(ActionEvent e)
            {
                formation.palettetype = PALETTE_STANDARD;
            }
        });

        jrbTypeOptimize = new JRadioButton(Resource.FormatPaletteOptimized);
        jrbTypeOptimize.addActionListener(new ActionListener()
        {
            public void actionPerformed(ActionEvent e)
            {
                formation.palettetype = PALETTE_OPTIMIZED;
            }
        });

        bgType.add(jrbTypeStandard);
        bgType.add(jrbTypeOptimize);

        jpPaletteType.add(jrbTypeStandard);
        jpPaletteType.add(jrbTypeOptimize);

        bgSize = new ButtonGroup();

        jpSize = new JPanel();
        jpSize.setBorder(
            BorderFactory.createTitledBorder(Resource.FormatImageSize));
        jpSize.setLayout(new BoxLayout(jpSize, BoxLayout.Y_AXIS));

        jrbSizeSmall = new JRadioButton(Resource.FormatImageSizeSmall);
        jrbSizeSmall.addActionListener(new ActionListener()
        {
            public void actionPerformed(ActionEvent e)
            {
                jtfWidth.setEnabled(false);
                jtfHeight.setEnabled(false);

                formation.width = 16;
                formation.height = 16;
            }
        });

        jrbSizeNormal = new JRadioButton(Resource.FormatImageSizeNormal);
        jrbSizeNormal.addActionListener(new ActionListener()
        {
            public void actionPerformed(ActionEvent e)
            {
                jtfWidth.setEnabled(false);
                jtfHeight.setEnabled(false);

                formation.width = 32;
                formation.height = 32;
            }
        });

        jrbSizeLarge = new JRadioButton(Resource.FormatImageSizeLarge);
        jrbSizeLarge.addActionListener(new ActionListener()
        {
            public void actionPerformed(ActionEvent e)
            {
                jtfWidth.setEnabled(false);
                jtfHeight.setEnabled(false);

                formation.width = 48;
                formation.height = 48;
            }
        });

        jrbCustom = new JRadioButton(Resource.FormatImageSizeCustom);
        jrbCustom.addActionListener(new ActionListener()
        {
            public void actionPerformed(ActionEvent e)
            {
                jtfWidth.setEnabled(true);
                jtfHeight.setEnabled(true);

                try
                {
                    formation.width =
                        Integer.valueOf(jtfWidth.getText()).intValue();
                    formation.height =
                        Integer.valueOf(jtfHeight.getText()).intValue();
                }
                catch (Exception exception)
                {
                    formation.width = 0;
                    formation.height = 0;
                }
            }
        });

        bgSize.add(jrbSizeSmall);
        bgSize.add(jrbSizeNormal);
        bgSize.add(jrbSizeLarge);
        bgSize.add(jrbCustom);

        JPanel panel = new JPanel();

        jtfWidth = new JTextField(2);
        lbCross = new JLabel("X");
        jtfHeight = new JTextField(2);
        panel.add(jtfWidth);
        panel.add(lbCross);
        panel.add(jtfHeight);

        jpSize.add(jrbSizeSmall);
        jpSize.add(jrbSizeNormal);
        jpSize.add(jrbSizeLarge);
        jpSize.add(jrbCustom);
        jpSize.add(panel);

        jpTop = new JPanel();
        jpTop.setLayout(new GridLayout(1, 3));
        jpTop.add(jpColors);
        jpTop.add(jpPaletteType);
        jpTop.add(jpSize);

        jbOK = new JButton(Resource.DialogOK);
        jbOK.addActionListener(new ActionListener()
        {
            public void actionPerformed(ActionEvent e)
            {
                if (jrbCustom.isSelected())
                {
                    try
                    {
                        formation.width =
                            Integer.valueOf(jtfWidth.getText()).intValue();
                        formation.height =
                            Integer.valueOf(jtfHeight.getText()).intValue();
                    }
                    catch (Exception exception)
                    {
                        formation.width = 0;
                        formation.height = 0;
                    }
                }

                if (formation.width == 0 || formation.height == 0)
                    JOptionPane.showMessageDialog(
                        ImageFormat.this,
                        Resource.FormatIllegalSize,
                        Resource.FormatDialogTitle,
                        JOptionPane.WARNING_MESSAGE);
                else
                {
                    succeed = true;
                    ImageFormat.this.dispose();
                }
            }

        });

        jbCancel = new JButton(Resource.DialogCancel);
        jbCancel.addActionListener(new ActionListener()
        {
            public void actionPerformed(ActionEvent e)
            {
                ImageFormat.this.dispose();
            }

        });

        jpBottom = new JPanel();
        jpBottom.add(jbOK);
        jpBottom.add(jbCancel);

        getContentPane().add(jpTop, "North");
        getContentPane().add(lbColors, "Center");
        getContentPane().add(jpBottom, "South");

        getRootPane().setDefaultButton(jbOK);
        pack();
        setResizable(false);
        setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
    }
}
