package skeleton;
import fsdi.*;

import components.mainframe.*;
import components.animation.*;
import components.preview.*;
import components.toolbox.*;
import components.palette.*;

import java.awt.*;
import javax.swing.*;

/**
 * @author 
 * <p>&copy;Ȩ 2002, 2003
 * 廪ѧѧԺ</p>
 * @version
 * 1.00
 * <p></p>*/

public class MainFrame extends FFrame
{
    private JDesktopPane desktop;
    private AManager manager;

    private AMenuBar jmbMenuBar;
    private AToolBar jtbToolBar;
    private JPanel tbPanel;
    private AStatusBar sbStatusBar;

    private AnimationPanel editview;
    private PreviewPanel preview;
    private ToolBoxPanel toolbox;
    private PalettePanel palette;

    protected void onPreCreateFrame()
    {
        desktop = new JDesktopPane();
        manager = new AManager(this, desktop);
        desktop.setDesktopManager(manager);
        getContentPane().add(new JScrollPane(desktop));

        jmbMenuBar = new AMenuBar(this);
        jtbToolBar = new AToolBar(this);

        JToolBar jtb = new JToolBar();
        jtb.add(jmbMenuBar);

        sbStatusBar = new AStatusBar();

        setJMenuBar(jmbMenuBar);
        tbPanel = new JPanel();
        tbPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
        tbPanel.add(jtbToolBar);
        getContentPane().add("North", tbPanel);

        getContentPane().add("South", sbStatusBar);
        setIconImage(Resource.IconMainFrame);
    }

    public void onAbout()
    {
        new AboutDlg(
            this,
            Resource.AboutDlgTitle,
            Resource.IconAllegretto,
            Resource.AboutDlgContent,
            null);
    }

    public String setStatus(String Status)
    {
        return sbStatusBar.setStatus(Status);
    }

    protected Dimension onCalculateWindow()
    {
        return new Dimension(
            Resource.FrameInitialWidth,
            Resource.FrameInitialHeight);
    }

    public Component addInternalFrame(Component internalFrame)
    {
        return desktop.add(internalFrame);
    }

    public void activeInternalFrame(JInternalFrame f)
    {
        manager.activateFrame(f);
    }

    public void onUpdate()
    {
        jmbMenuBar.updateMenu();
        jtbToolBar.updateToolBar();
    }

    public MainFrame(AnimationDoc doc, String AppName, String[] args)
    {
        super(doc, AppName, args);
        setStatus(Resource.StatusReady);

        palette = new PalettePanel(this);
        addInternalFrame(palette);
        palette.setLocation(
            Resource.FrameInitialWidth - palette.getWidth() - 5,
            0);

        toolbox = new ToolBoxPanel(this);
        addInternalFrame(toolbox);

        editview = new AnimationPanel();
        editview.setLocation(toolbox.getWidth(), 0);
        addView(editview);

        preview = new PreviewPanel();
        addView(preview);
    }

    public boolean isToolBarVisible()
    {
        return jtbToolBar.isVisible();
    }

    public boolean isStatusBarVisible()
    {
        return sbStatusBar.isVisible();
    }

    public void setStatusBarVisible(boolean visible)
    {
        sbStatusBar.setVisible(visible);
    }

    public AnimationPanel getAnimation()
    {
        return editview;
    }

    public PreviewPanel getPreview()
    {
        return preview;
    }

    public ToolBoxPanel getToolBox()
    {
        return toolbox;
    }

    public PalettePanel getPalette()
    {
        return palette;
    }

    public JInternalFrame getActiveFrame()
    {
        return desktop.getSelectedFrame();
    }
}
